##  Grant Permissions to SAP LeanIX
After registering SAP LeanIX, the next step is to grant the necessary permissions to call APIs.
  1. On the left pane, click API permissions.
  2. Click Add a permission.
![Granting API Permission](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e1f057a441014bf6a8df63e7129b8_LowRes.png)
Granting API Permission
  3. In the overlay for requesting API permissions, search and select the Microsoft Graph API.
  4. Select Application permissions at the top, then search and select Application.Read.All permission from the list below.
  5. If you need usage indication capability, make sure to search for and select the Reports.Read.All permission as well.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e6aac7a441014b431c05b93bcbab2_LowRes.png)
  6. Click Add permissions at the bottom to assign permission to SAP LeanIX.
  7. On the API permissions page, click Grant admin consent for Default Directory to enable configured permissions.
  8. Click Yes and grant consent for the requested permissions.
  9. The permission status indicator in the API permissions page will change to approved.
